# code for analyses presented in PAG et al "Testing the conflict-cohesion hypothesis: effects of simulated territorial intrusions on metrics of social cohesion in banded mongooses (Mungos mungo)."
#this code combines two datasets and then runs the analyses presented in the main text. 

#clear history
rm(list = ls(all.names = TRUE))

# libraries
library(tidyverse)
library(psych)
library(car)
library(lme4)
library(glmmTMB)
library(performance)
library(multcomp)
library(wesanderson)

# datasets
setwd(choose.dir())
beh <- as_tibble(read.csv("behaviour_data.csv", header=TRUE, stringsAsFactors = FALSE))
names(beh)<-tolower(names(beh))
prop <- as_tibble(read.csv("approach_data.csv", header=TRUE, stringsAsFactors = FALSE))
names(prop)<-tolower(names(prop))

#join beh with prop by video & time
d <- full_join(beh, prop, by = c("video", "time"))
#keep only the needed columns
d <- d[,c(1:13, 19:23)]
#rename columns for ease
names(d) <- c("video", "treatment", "stimulus", "call", "time", "beh.type", "n.beh", "avg.h", "avg.h.bytime", "n.in.shot", "field.grp.sz", "vid.grp.sz", "loc", "prop.in.vid",
              "n.inside2m", "n.outside2m", "prop.in2m", "time.last2m")

#add new variables
d <- d%>%
  mutate(short.beh = ifelse(d$beh.type=="Stationary", "St",  #shorter, simpler behavior names
                            ifelse(d$beh.type=="Walk/run", "W/R",
                                   ifelse(d$beh.type=="Attacking", "A",
                                          ifelse(d$beh.type=="Standing", "V", #for "vigilence"
                                                 ifelse(d$beh.type=="Marking", "M",
                                                        ifelse(d$beh.type=="Digging", "D", NA)))))))
d <- d%>%
  mutate(defense = as.factor(ifelse(d$short.beh=="A" | d$short.beh=="V" | d$short.beh=="M", "defense", "not.defense"))) #set defense v. not defense behaviors

d$time <- as.factor(d$time)

#simplify the dataset even further, summarizing to only the # of defensive & not defensive behaviors
d2.def <- d%>% #dataset of only defense behaviors
  group_by(video, treatment, stimulus)%>%
  filter(defense=="defense")%>%
  group_by(video, treatment, stimulus,time)%>%
  summarise(n.def = sum(n.beh, na.action=NULL))

d2.notdef <- d%>% #dataset of only not defensive behaviors
  group_by(video, treatment, stimulus)%>%
  filter(defense=="not.defense")%>%
  group_by(video, treatment, stimulus,time)%>%
  summarise(n.notdef = sum(n.beh, na.action=NULL))

d2.def.notdef <- full_join(d2.def, d2.notdef, by = c("video", "time"))[,-c(6:7)] #join the two

d3 <- full_join(d2.def.notdef, d, by = c("video", "time")) #join these w/ the original dataset

d3$stim <- as.factor(paste(tolower(substr(d3$treatment, 1,1)), tolower(d3$stimulus), sep = "_"))#make a new name for stimulus

#reorganize so that calls and scents are distinct
d3$stim <- ifelse(d3$stim=="c_scents" & d3$call=="pre-call", "c_scents", 
                  ifelse(d3$stim=="c_scents" & d3$call=="post-call", "c_call",
                         ifelse(d3$stim=="t_scents" & d3$call=="pre-call", "t_scents",
                                ifelse(d3$stim=="t_scents" & d3$call=="post-call", "t_call",
                                       ifelse(d3$stim=="c_intruders", "c_intruders", "t_intruders")))))

#create an h-index metric that is the mean h-index value for each stimulus type
d3 <- d3%>%
  group_by(video, stim)%>%
  mutate(avg.h.bystim = mean(avg.h.bytime, na.rm=TRUE))

#create a variable for the proportion of group members acting defensively
d3 <- d3%>%
  group_by(video, stim, short.beh)%>%
  mutate(sum.beh = sum(n.beh, na.rm = TRUE))%>%
  mutate(prop.def = n.def/(n.def + n.notdef))%>%
  mutate(grp.sz.cat = as.factor(ifelse(field.grp.sz>17.5, "large", "small")))#ended up not using group size categories.

#see if there are videos that have fewer than 2 30s samples per stimulus
timesamples <- d3%>%
  group_by(video,stim)%>%
  filter(!is.na(prop.in2m))%>%
  filter(!is.na(prop.def))%>%
  filter(!is.na(avg.h.bystim))%>%
  summarise(n.samples = length(unique(time)))%>%
  arrange(n.samples)

timesamples%>%
  filter(n.samples<2)
#many of the call stimuli (but not the corresponding scent stimuli for the same videos)
#also identified a few in analysis that weren't found here.

#drop these b/c they're really poorly sampled
#this is very clunky, but oh well.
nrow(d3)#3192
d3 <- d3[-which(d3$stim=="c_call" & d3$video=="11C3AM"),]
nrow(d3)#3174 = 18 gone 
d3 <- d3[-which(d3$stim=="t_call" & d3$video=="26R2AM"),]
nrow(d3)#3156 = -18
d3 <- d3[-which(d3$stim=="t_call" & d3$video=="2R2AM"),]
nrow(d3)#3132 = -24
d3 <- d3[-which(d3$stim=="c_call" & d3$video=="1BC2AM"),]#this video had NA values for vid.grp.sz b/c Megan couldn't count # in frame (not all were in view at any given time)
nrow(d3)#3114 = -18
d3 <- d3[-which(d3$stim=="t_call" & d3$video=="2R3AM"),]
nrow(d3)#3096 = -18

#try taking the mean value for proportion data at each timepoint. 
d3 <- d3%>%
  group_by(video, time)%>%
  mutate(time.mean.prop.def = n.def/(n.def+n.notdef))%>%
  mutate(time.mean.prop2m = n.inside2m/(n.inside2m + n.outside2m))%>%
  group_by(video, stim)%>%
  mutate(stim.mean.propdef = mean(time.mean.prop.def, na.rm=TRUE))%>% #setting na.rm = TRUE here--to prevent NA from one time sample from causing the whole stimulus to have NAs.
  mutate(stim.mean.prop2m = mean(time.mean.prop2m, na.rm=TRUE)) #same here. 

#useful to do a check of the data to be sure this did things correctly
#replace the video name to go through a few examples
checkvid <- sample(d$video, 1)
View(d[d$video==checkvid,])
View(d3[d3$video==checkvid,])
#looks good!!!

###
#remove unnecessary columns
d3 <- d3[,c("video","stim","loc","field.grp.sz", "vid.grp.sz", "grp.sz.cat","avg.h","avg.h.bystim","short.beh","sum.beh",
            "time.mean.prop.def","stim.mean.propdef", "time.mean.prop2m", "stim.mean.prop2m")]

d3 <- distinct(d3) #save only distinct rows of d3, i.e., remove replicates

d3 <- d3%>%
  group_by(video, stim)%>%
  slice(1:6)

#calculate the proportion doing a given behavior
d3 <- d3%>%
  group_by(video, stim)%>%
  mutate(all.beh.sum = sum(sum.beh))%>%
  group_by(short.beh)%>%
  mutate(prop.beh = sum.beh / all.beh.sum)

#make sure some things are factors
d3$grp <- as.factor(substr(d3$video, 1, 2))
d3$loc <- as.factor(d3$loc)
#reorder the levels of stimulus so it's easier to understand
d3$stim <- factor(d3$stim, levels = c("c_scents", "t_scents", "c_call", "t_call", "c_intruders", "t_intruders"))

#reorder columns
d3 <- d3[,c("video", "grp", "stim", "loc", "field.grp.sz" , "vid.grp.sz", "grp.sz.cat", "avg.h.bystim", "short.beh", "sum.beh", "prop.beh",  
             "time.mean.prop.def", "stim.mean.propdef", "time.mean.prop2m", "stim.mean.prop2m")]

#view one more time
View(d3)
#check things in case anything needs to be checked

#save over d
d.backup <- d
d <- d3

##### 
# SUMMARY STATS
#####

#how many na values?
d%>%
  group_by(video,stim)%>%
  slice(1)%>%
  filter(is.na(stim))#6 for stimulus

d%>%
  group_by(video,stim)%>%
  slice(1)%>%
  filter(is.na(loc))#7 for location

d%>%
  group_by(video,stim)%>%
  slice(1)%>%
  filter(is.na(field.grp.sz))#0 for group size

d%>%
  group_by(video,stim)%>%
  slice(1)%>%
  filter(!is.na(loc))%>%
  filter(!is.na(stim))#total of 86 points w/ NAs excluded

#how many trials per stimulus?
d%>%
  group_by(video, stim)%>%
  slice(1)%>%
  group_by(stim)%>%
  count(stim)

#per group
grp.data <- d%>%
  group_by(video, stim)%>%
  slice(1)%>%
  group_by(grp)%>%
  count(grp)
summary(grp.data)

d%>%
  group_by(video, stim)%>%
  slice(1)%>%
  group_by(loc)%>%
  count(loc)

#what is variation within groups?
d%>%group_by(grp)%>%summarise(min(field.grp.sz), max(field.grp.sz))

#check that field group size and video group size are correlated
grp.sz.check <- d[complete.cases(d),]
cor(grp.sz.check$field.grp.sz, grp.sz.check$vid.grp.sz, method = "pearson")
plot(grp.sz.check$field.grp.sz~grp.sz.check$vid.grp.sz)

#####
# MODELING
#####

#Prop w/in 2m data
#isolate only the relevant data
prop2mdata <- d%>%
  filter(!grepl("call", stim))%>%
  group_by(video, stim)%>%
  slice(1)

prop2mdata <- prop2mdata[,c("video", "grp", "stim", "loc", "field.grp.sz", "grp.sz.cat", "stim.mean.prop2m")]

nrow(prop2mdata)#74--fewer than 86 b/c we've removed call treatment
prop2mdata <- prop2mdata[complete.cases(prop2mdata),]#removed NAs for stim, loc, and one for prop2m variable
nrow(prop2mdata)#62

#make transformed stim.mean.prop2m
prop2mdata$trans.y<-(prop2mdata$stim.mean.prop2m*(length(prop2mdata$stim.mean.prop2m)-1)+0.5)/(length(prop2mdata$stim.mean.prop2m))
hist(prop2mdata$trans.y)
summary(prop2mdata$trans.y)
qqnorm(prop2mdata$trans.y)
qqline(prop2mdata$trans.y)

#run full model
full2mmodel <- glmmTMB(trans.y~stim + field.grp.sz + loc +
                    stim:field.grp.sz + stim:loc + field.grp.sz:loc +
                    (1|grp), data=prop2mdata,family=beta_family)
#check model output and fit
summary(full2mmodel)
hist(resid(full2mmodel))#residuals are normally-distributed
qqnorm(resid(full2mmodel))
qqline(resid(full2mmodel))

#test for significance of interaction terms
drop1(full2mmodel,test="Chi")

#reduced model w/ no interactions
reduced2mmodel <- glmmTMB(trans.y~stim + field.grp.sz + loc +
                         (1|grp), data=prop2mdata,family=beta_family)
summary(reduced2mmodel)
hist(resid(reduced2mmodel))
qqnorm(resid(reduced2mmodel))
qqline(resid(reduced2mmodel))

#test for significance of fixed effects
drop1(reduced2mmodel,test="Chi")

#post-hoc tests
summary(glht(reduced2mmodel, linfct = mcp(stim = c("t_scents - c_scents = 0",
                                                   "t_intruders - c_intruders = 0"))))

#summary data
prop2mdata%>%
  group_by(stim)%>%
  summarise(mean(stim.mean.prop2m), sd(stim.mean.prop2m))

#plotting
#create data for plotting model estimates
newdata<-with(prop2mdata,
              expand.grid(
                stim = c("c_scents", "t_scents", "c_intruders", "t_intruders"),
                field.grp.sz = mean(field.grp.sz),
                loc = c("Core", "Non-core"),
                trans.y=0,
                grp=NA) # Have to set the random effect to NA to be able to get model predictions in glmmTMB with beta distribution.
)

model_predictions<-predict(reduced2mmodel,newdata,se.fit=TRUE,type="response") # These are already backtransformed from the reponse scale so are ready to plot

## Get predictions and standard errors
newdata$y<-model_predictions$fit
newdata$pred.se.min<-model_predictions$fit-model_predictions$se.fit
newdata$pred.se.max<-model_predictions$fit+model_predictions$se.fit

plotnewdata <- newdata%>%
  group_by(stim)%>%
  summarise(mean(y), mean(pred.se.min), mean(pred.se.max))
names(plotnewdata) <- c("stim", "stim.mean.prop2m", "pred.se.min", "pred.se.max")

#make the plot

#to investigate data from oestrus groups, feel free to add an oestrus variable for the 3 videos in which focal group was in oestrus
#prop2mdata$oes <- ifelse(grepl("11C3", prop2mdata$video) | grepl("26R1", prop2mdata$video) | grepl("2R1", prop2mdata$video), "oes", "not.oes")
#then add oes as a color in the plot (see below)

#make the plot--Figure 2a
ggplot(d = prop2mdata, aes(x = stim, y = stim.mean.prop2m))+#, col = oes))+
  geom_jitter(width = 0.05, alpha = 0.25, pch=ifelse(grepl("c_", prop2mdata$stim), 17,19), cex=2.5)+
  geom_point(d = plotnewdata, aes(x = stim, y = stim.mean.prop2m), shape = rep(c(17,19),2), cex = 4)+
  geom_linerange(d = plotnewdata, aes(x=stim,ymin=pred.se.min,ymax=pred.se.max),size=1.5,position=position_dodge(width=0.25)) +
  scale_y_continuous(limits = c(-0.05, 1.05))+
  xlab("Stimulus")+
  ylab("Proportion approaching stimulus")+
  scale_x_discrete(labels = c("c_scents" = "Scents", "t_scents" = "",
                              "c_intruders" = "Intruders", "t_intruders" = ""))+
  theme_bw()+
  theme(text = element_text(size = 14), axis.text.y = element_text(size = 12), axis.text.x = element_text(size = 12))

#save the plot
#ggsave("Figure_2a.png", dpi=300, height=5, width=5, units="in")

#plotting group size effects
newdata<-with(prop2mdata,
              expand.grid(
                stim = c("c_scents", "t_scents", "c_intruders", "t_intruders"),
                field.grp.sz = seq(min(field.grp.sz), max(field.grp.sz), 1),
                loc = c("Core", "Non-core"),
                trans.y=0,
                grp=NA) # Have to set the random effect to NA to be able to get model predictions in glmmTMB with beta.
)

model_predictions<-predict(reduced2mmodel,newdata,se.fit=TRUE,type="response") # These are already backtransformed from the reponse scale so are ready to plot

## Get predictions and standard errors
newdata$y<-model_predictions$fit
newdata$pred.se.min<-model_predictions$fit-model_predictions$se.fit
newdata$pred.se.max<-model_predictions$fit+model_predictions$se.fit

plotnewdata <- newdata%>%
  group_by(field.grp.sz)%>%
  summarise(mean(y), mean(pred.se.min), mean(pred.se.max))
names(plotnewdata) <- c("field.grp.sz", "stim.mean.prop2m", "pred.se.min", "pred.se.max")

#make the plot--Figure 2b
ggplot(data = prop2mdata, aes(x = field.grp.sz, y = stim.mean.prop2m))+#, col = oes))+
  geom_point()+
  geom_line(data = plotnewdata, aes(x = field.grp.sz, y = stim.mean.prop2m), lwd = 1)+
  geom_ribbon(data = plotnewdata, aes(ymin = pred.se.min, ymax = pred.se.max), alpha = 0.25)+
  ylim(c(-0.05, 1.05))+
  xlab("Group size")+
  ylab("Proportion approaching stimulus")+
  theme_bw()+
  theme(text = element_text(size = 14), axis.text = element_text(size = 12))

#ggsave("Figure_2b.png" dpi=300, height=5, width=5, units="in")

####
#Prop acting defensively
#isolate only the relevant data
propdefdata <- d%>%
  group_by(video, stim)%>%
  slice(1)

propdefdata <- propdefdata[,c("video", "grp", "stim", "loc", "field.grp.sz", "stim.mean.propdef")]

nrow(propdefdata)#99
propdefdata <- propdefdata[complete.cases(propdefdata),]
nrow(propdefdata)#82

propdefdata$trans.y<-(propdefdata$stim.mean.propdef*(length(propdefdata$stim.mean.propdef)-1)+0.5)/(length(propdefdata$stim.mean.propdef))
hist(propdefdata$trans.y)#big right skew here--but the model residuals are what really matters
summary(propdefdata$trans.y)
qqnorm(propdefdata$trans.y)
qqline(propdefdata$trans.y)

#build full model
fulldefmodel <- glmmTMB(trans.y~stim + field.grp.sz + loc +
                         stim:field.grp.sz + stim:loc + field.grp.sz:loc +
                         (1|grp), data=propdefdata,family=beta_family)
#test model fit
summary(fulldefmodel)
hist(resid(fulldefmodel))# normally-distributed residuals
qqnorm(resid(fulldefmodel))
qqline(resid(fulldefmodel))

#test significance of interaction terms
drop1(fulldefmodel,test="Chi")

#build reduced model
reduceddefmodel <- glmmTMB(trans.y~stim + field.grp.sz + loc +
                            (1|grp), data=propdefdata,family=beta_family)
summary(reduceddefmodel)
hist(resid(reduceddefmodel))
qqnorm(resid(reduceddefmodel))
qqline(resid(reduceddefmodel))

#test significance of fixed effects
drop1(reduceddefmodel,test="Chi")

#post-hoc tests
summary(glht(reduceddefmodel, linfct = mcp(stim = c("t_scents - c_scents = 0",
                                                    "t_call - c_call = 0",
                                                    "t_intruders - c_intruders = 0"))))

#summary stats of main effects
propdefdata%>%
  group_by(stim)%>%
  summarise(mean(stim.mean.propdef), sd(stim.mean.propdef))

#plotting
newdata<-with(propdefdata,
              expand.grid(
                stim = c("c_scents", "t_scents", "c_call", "t_call", "c_intruders", "t_intruders"),
                field.grp.sz = mean(field.grp.sz),
                loc = c("Core", "Non-core"),
                trans.y=0,
                grp=NA) # Have to set the random effect to NA to be able to get model predictions in glmmTMB with beta.
)

model_predictions<-predict(reduceddefmodel,newdata,se.fit=TRUE,type="response") # These are already backtransformed from the reponse scale so are ready to plot

## Get predictions and standard errors
newdata$y<-model_predictions$fit
newdata$pred.se.min<-model_predictions$fit-model_predictions$se.fit
newdata$pred.se.max<-model_predictions$fit+model_predictions$se.fit

plotnewdata <- newdata%>%
  group_by(stim)%>%
  summarise(mean(y), mean(pred.se.min), mean(pred.se.max))
names(plotnewdata) <- c("stim", "stim.mean.propdef", "pred.se.min", "pred.se.max")

#make the plot--Figure 3
ggplot(d = propdefdata, aes(x = stim, y = stim.mean.propdef))+#, col = oes))+
  geom_jitter(width = 0.05, alpha = 0.25, pch=ifelse(grepl("c_", propdefdata$stim), 17,19), cex=2.5)+
  geom_point(d = plotnewdata, aes(x = stim, y = stim.mean.propdef), shape = rep(c(17,19),3), cex = 4)+
  geom_linerange(d = plotnewdata, aes(x=stim,ymin=pred.se.min,ymax=pred.se.max),size=1.5,position=position_dodge(width=0.25)) +
  scale_y_continuous(limits = c(-0.05, 1.05))+
  xlab("Stimulus")+
  ylab("Proportion acting defensively")+
  scale_x_discrete(labels = c("c_scents" = "Scents", "t_scents" = "",
                              "c_call"= "Calls", "t_call" = "",
                              "c_intruders" = "Intruders", "t_intruders" = ""))+
  theme_bw()+
  theme(text = element_text(size = 14), axis.text.y = element_text(size = 12), axis.text.x = element_text(size = 12))

#save the plot
#ggsave("Figure_3a.png" dpi=300, height=5, width=5, units="in")

#####
# H-index 
#isolate only the relevant data
Hdata <- d%>%
  group_by(video, stim)%>%
  slice(1)
Hdata <- Hdata[,c("video", "grp", "stim", "loc", "field.grp.sz", "avg.h.bystim")]

nrow(Hdata)#99
Hdata <- Hdata[complete.cases(Hdata),]
nrow(Hdata)#82--removed a few instances where there was incomplete data

#build the full model
fullHmodel <- glmmTMB(data = Hdata, formula = avg.h.bystim ~ stim + field.grp.sz + loc +
                          stim:field.grp.sz + stim:loc + field.grp.sz:loc +
                     (1|grp))
summary(fullHmodel)
hist(residuals(fullHmodel))

#test interaction term significance
drop1(fullHmodel, test = "Chisq")

#build reduced model
reducedHmodel <- glmmTMB(data = Hdata, formula = avg.h.bystim ~ 
                           stim + field.grp.sz + loc +
                           (1|grp))
summary(reducedHmodel)
hist(residuals(reducedHmodel))

#test for significance of fixed effects
drop1(reducedHmodel, test = "Chisq") 
#note there is a "convergence problem" w/ the model avg.h.bystim ~ field.grp.sz + loc + (1|grp). This is not a problem using lmer, only glmmTMB.
#the estimates are the same between glmmTMB and lmer, suggesting the model still gives good estimates & can be used. 
#if desired, build reducedHmodel using lmer() and run drop1(). The results are the same.  

#post-hoc tests
summary(glht(reducedHmodel, linfct = mcp(stim = c("t_scents - c_scents = 0",
                                                  "t_call - c_call = 0",
                                                  "t_intruders - c_intruders = 0"))))

#summary statistics of significant effects
Hdata%>%
  group_by(stim)%>%
  summarise(mean(avg.h.bystim), sd(avg.h.bystim))

#plotting these effects
newdata <- with(Hdata,
                expand.grid(
                  stim = c("c_scents", "t_scents", "c_call", "t_call", "c_intruders", "t_intruders"),
                  field.grp.sz = mean(field.grp.sz),
                  loc = c("Core", "Non-core"),
                  avg.h.bystim=0,
                  grp=NA
                ))

model_predictions<-predict(reducedHmodel,newdata,se.fit=TRUE,type="response") # These are already backtransformed from the reponse scale so are ready to plot

## Get predictions and standard errors
newdata$y<-model_predictions$fit
newdata$pred.se.min<-model_predictions$fit-model_predictions$se.fit
newdata$pred.se.max<-model_predictions$fit+model_predictions$se.fit

#get mean values
plotnewdata <- newdata%>%
  group_by(stim)%>%
  summarise(mean(y), mean(pred.se.min), mean(pred.se.max))
names(plotnewdata) <- c("stim", "avg.h.bystim", "pred.se.min", "pred.se.max")

#plot data
#oestrus status, if desired
#Hdata$oes <- ifelse(grepl("11C3", Hdata$video) | grepl("26R1", Hdata$video) | grepl("2R1", Hdata$video), "oes", "not.oes")

#stimulus effect--Fig. 4a
ggplot(d = Hdata, aes(x = stim, y = avg.h.bystim))+#, col = oes))+
  geom_jitter(width = 0.05, alpha = 0.25, pch=ifelse(grepl("c_", Hdata$stim), 17,19), cex=2.5)+
  geom_point(d = plotnewdata, aes(x = stim, y = avg.h.bystim), shape = rep(c(17,19),3), cex = 4)+
  geom_linerange(d = plotnewdata, aes(x=stim,ymin=pred.se.min,ymax=pred.se.max),size=1.5,position=position_dodge(width=0.25)) +
  scale_y_continuous(limits = c(-0.05, 1.05))+
  xlab("Stimulus")+
  ylab("H-index")+
  scale_x_discrete(labels = c("c_scents" = "Scents", "t_scents" = "",
                              "c_call"= "Calls", "t_call" = "",
                              "c_intruders" = "Intruders", "t_intruders" = ""))+
  theme_bw()+
  theme(text = element_text(size = 14), axis.text.y = element_text(size = 12), axis.text.x = element_text(size = 12))

#ggsave("Figure_4a.png", dpi=300, height=5, width=5, units="in")

#group size effect
newdata <- with(Hdata,
                expand.grid(
                  stim = c("c_scents", "t_scents", "c_call", "t_call", "c_intruders", "t_intruders"),
                  field.grp.sz = seq(min(field.grp.sz), max(field.grp.sz), 1),
                  loc = c("Core", "Non-core"),
                  avg.h.bystim=0,
                  grp=NA
                ))

model_predictions<-predict(reducedHmodel,newdata,se.fit=TRUE,type="response") # These are already backtransformed from the reponse scale so are ready to plot

## Get predictions and standard errors
newdata$y<-model_predictions$fit
newdata$pred.se.min<-model_predictions$fit-model_predictions$se.fit
newdata$pred.se.max<-model_predictions$fit+model_predictions$se.fit

#get mean values
plotnewdata <- newdata%>%
  group_by(field.grp.sz)%>%
  summarise(mean(y), mean(pred.se.min), mean(pred.se.max))

names(plotnewdata) <- c("field.grp.sz", "avg.h.bystim", "pred.se.min", "pred.se.max")

#Figure 4b
ggplot(data = Hdata, aes(x = field.grp.sz, y = avg.h.bystim))+#, col = oes))+
  geom_point()+
  geom_line(data = plotnewdata, aes(x = field.grp.sz, y = avg.h.bystim), lwd = 1)+
  geom_ribbon(data = plotnewdata, aes(ymin = pred.se.min, ymax = pred.se.max), alpha = 0.25)+
  ylim(c(-0.05, 1.05))+
  xlab("Group size")+
  ylab("H-index")+
  theme_bw()+
  theme(text = element_text(size = 14), axis.text = element_text(size = 12))

#ggsave("Figure_4b.png", dpi=300, height=5, width=5, units="in")

#plotting behavioral data to lend insight to h-index data
plotdata <- d%>%
  group_by(stim, short.beh)%>%
  summarise(mean.prop.beh = mean(prop.beh, na.rm = TRUE))

plotdata$short.beh <- as.factor(plotdata$short.beh)
plotdata$short.beh <- factor(plotdata$short.beh, levels = c("W/R", "St", "D", "V", "M", "A"))
plotdata$short.beh <- factor(plotdata$short.beh, levels = c("A", "M", "V", "W/R", "St", "D"))

#set colors to be reds for defensive behaviours and blues for not defensive behaviors
notdefbehcols <- c("#d8daeb", "#998ec3", "#542788")
defbehcols <- c("#b35806", "#f1a340", "#fee0b6")
allcols <- c(defbehcols, notdefbehcols)

#Figure 4c
ggplot(data = plotdata[!is.na(plotdata$stim),], aes(fill=short.beh, x = stim, y = mean.prop.beh))+
  geom_bar(stat = "identity", position = position_stack(reverse = FALSE))+
  scale_fill_manual(values = allcols)+
  xlab("Stimulus")+
  ylab("Proportion of group showing each behavior")+
  scale_x_discrete(labels = c("c_scents" = "Scents", "t_scents" = "",
                              "c_call"= "Calls", "t_call" = "",
                              "c_intruders" = "Intruders", "t_intruders" = ""))+
  theme_bw()+
  theme(text = element_text(size = 14), axis.text.y = element_text(size = 12), axis.text.x = element_text(size = 12))

#ggsave("Figure_4c.png", dpi=300, height=5, width=5, units="in")